import { system, world, BlockPermutation, Direction } from '@minecraft/server';
import { decrementStack, getOppositeDirection, DirectionType, cardinalSides } from './utils/helper';
import { directionToVector3 } from './utils/math';

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent('tbc_arbusto_guarana:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 3) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tbc_capim_dourado:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 4) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tbc_erva_mate:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 4) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_laje_jacaranda:trigger', {
  beforeOnPlayerPlace: e => { let playerEquipment = e.player.getComponent('equippable').getEquipment('Mainhand');
if (playerEquipment === undefined)
    return;
let face = getOppositeDirection(e.face);
let blockToCheck = e.block.offset(directionToVector3(face));
const blockStateDouble = 'pa:is_double';
const blockStateHalf = 'minecraft:vertical_half';
if (blockToCheck.permutation.getState(blockStateDouble))
    return;
if (blockToCheck.typeId !== playerEquipment.typeId)
    return;
if (face === 'Up' || face === 'Down') {
    const state = blockToCheck.permutation.getState(blockStateHalf);
    if ((face === 'Up' && state === 'top') ||
        (face === 'Down' && state === 'bottom')) {
        blockToCheck.dimension.playSound("use.wood", blockToCheck.location, { pitch: 0.8, volume: 1.0 });
        blockToCheck.setPermutation(BlockPermutation.resolve(blockToCheck.typeId, {
            [blockStateDouble]: true
        }));
        e.cancel = true;
        decrementStack(player);
    }
}
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_escada_jacanrada:trigger', {
  beforeOnPlayerPlace: e => { let face = e.permutationToPlace.getState('minecraft:cardinal_direction');
let half = e.permutationToPlace.getState('minecraft:vertical_half');
let blockPermutation = e.permutationToPlace;
let blockToCheck;
switch (face) {
    case 'north':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'south':
        {
            blockPermutation = blockPermutation.withState('pa:south', true);
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'east':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'west':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    default:
        break;
}
e.permutationToPlace = blockPermutation;
e.block.dimension.playSound("use.wood", e.block.location, { pitch: 0.8, volume: 1.0 });
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_laje_pau_brasil:trigger', {
  beforeOnPlayerPlace: e => { let playerEquipment = e.player.getComponent('equippable').getEquipment('Mainhand');
if (playerEquipment === undefined)
    return;
let face = getOppositeDirection(e.face);
let blockToCheck = e.block.offset(directionToVector3(face));
const blockStateDouble = 'pa:is_double';
const blockStateHalf = 'minecraft:vertical_half';
if (blockToCheck.permutation.getState(blockStateDouble))
    return;
if (blockToCheck.typeId !== playerEquipment.typeId)
    return;
if (face === 'Up' || face === 'Down') {
    const state = blockToCheck.permutation.getState(blockStateHalf);
    if ((face === 'Up' && state === 'top') ||
        (face === 'Down' && state === 'bottom')) {
        blockToCheck.dimension.playSound("use.wood", blockToCheck.location, { pitch: 0.8, volume: 1.0 });
        blockToCheck.setPermutation(BlockPermutation.resolve(blockToCheck.typeId, {
            [blockStateDouble]: true
        }));
        e.cancel = true;
        decrementStack(player);
    }
}
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_escada_pau_brasil:trigger', {
  beforeOnPlayerPlace: e => { let face = e.permutationToPlace.getState('minecraft:cardinal_direction');
let half = e.permutationToPlace.getState('minecraft:vertical_half');
let blockPermutation = e.permutationToPlace;
let blockToCheck;
switch (face) {
    case 'north':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'south':
        {
            blockPermutation = blockPermutation.withState('pa:south', true);
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'east':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'west':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    default:
        break;
}
e.permutationToPlace = blockPermutation;
e.block.dimension.playSound("use.wood", e.block.location, { pitch: 0.8, volume: 1.0 });
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_mandacaru:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 4) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_planta_camucamu:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 5) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_laje_arenito_areia_quartzo:trigger', {
  beforeOnPlayerPlace: e => { let playerEquipment = e.player.getComponent('equippable').getEquipment('Mainhand');
if (playerEquipment === undefined)
    return;
let face = getOppositeDirection(e.face);
let blockToCheck = e.block.offset(directionToVector3(face));
const blockStateDouble = 'pa:is_double';
const blockStateHalf = 'minecraft:vertical_half';
if (blockToCheck.permutation.getState(blockStateDouble))
    return;
if (blockToCheck.typeId !== playerEquipment.typeId)
    return;
if (face === 'Up' || face === 'Down') {
    const state = blockToCheck.permutation.getState(blockStateHalf);
    if ((face === 'Up' && state === 'top') ||
        (face === 'Down' && state === 'bottom')) {
        blockToCheck.dimension.playSound("use.stone", blockToCheck.location, { pitch: 0.8, volume: 1.0 });
        blockToCheck.setPermutation(BlockPermutation.resolve(blockToCheck.typeId, {
            [blockStateDouble]: true
        }));
        e.cancel = true;
        decrementStack(player);
    }
}
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_laje_arenito_areia_quartzo_liso:trigger', {
  beforeOnPlayerPlace: e => { let playerEquipment = e.player.getComponent('equippable').getEquipment('Mainhand');
if (playerEquipment === undefined)
    return;
let face = getOppositeDirection(e.face);
let blockToCheck = e.block.offset(directionToVector3(face));
const blockStateDouble = 'pa:is_double';
const blockStateHalf = 'minecraft:vertical_half';
if (blockToCheck.permutation.getState(blockStateDouble))
    return;
if (blockToCheck.typeId !== playerEquipment.typeId)
    return;
if (face === 'Up' || face === 'Down') {
    const state = blockToCheck.permutation.getState(blockStateHalf);
    if ((face === 'Up' && state === 'top') ||
        (face === 'Down' && state === 'bottom')) {
        blockToCheck.dimension.playSound("use.stone", blockToCheck.location, { pitch: 0.8, volume: 1.0 });
        blockToCheck.setPermutation(BlockPermutation.resolve(blockToCheck.typeId, {
            [blockStateDouble]: true
        }));
        e.cancel = true;
        decrementStack(player);
    }
}
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_laje_arenito_areia_quartzo_cortado:trigger', {
  beforeOnPlayerPlace: e => { let playerEquipment = e.player.getComponent('equippable').getEquipment('Mainhand');
if (playerEquipment === undefined)
    return;
let face = getOppositeDirection(e.face);
let blockToCheck = e.block.offset(directionToVector3(face));
const blockStateDouble = 'pa:is_double';
const blockStateHalf = 'minecraft:vertical_half';
if (blockToCheck.permutation.getState(blockStateDouble))
    return;
if (blockToCheck.typeId !== playerEquipment.typeId)
    return;
if (face === 'Up' || face === 'Down') {
    const state = blockToCheck.permutation.getState(blockStateHalf);
    if ((face === 'Up' && state === 'top') ||
        (face === 'Down' && state === 'bottom')) {
        blockToCheck.dimension.playSound("use.stone", blockToCheck.location, { pitch: 0.8, volume: 1.0 });
        blockToCheck.setPermutation(BlockPermutation.resolve(blockToCheck.typeId, {
            [blockStateDouble]: true
        }));
        e.cancel = true;
        decrementStack(player);
    }
}
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_escada_areia_dquartzo_liso:trigger', {
  beforeOnPlayerPlace: e => { let face = e.permutationToPlace.getState('minecraft:cardinal_direction');
let half = e.permutationToPlace.getState('minecraft:vertical_half');
let blockPermutation = e.permutationToPlace;
let blockToCheck;
switch (face) {
    case 'north':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'south':
        {
            blockPermutation = blockPermutation.withState('pa:south', true);
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'east':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'west':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    default:
        break;
}
e.permutationToPlace = blockPermutation;
e.block.dimension.playSound("use.stone", e.block.location, { pitch: 0.8, volume: 1.0 });
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_escada_areia_dquartzo_arenito:trigger', {
  beforeOnPlayerPlace: e => { let face = e.permutationToPlace.getState('minecraft:cardinal_direction');
let half = e.permutationToPlace.getState('minecraft:vertical_half');
let blockPermutation = e.permutationToPlace;
let blockToCheck;
switch (face) {
    case 'north':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'south':
        {
            blockPermutation = blockPermutation.withState('pa:south', true);
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'west') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'west') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'east') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'east':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    case 'west':
        {
            for (const direction of DirectionType.HORIZONTAL) {
                blockToCheck = e.block.offset(directionToVector3(direction));
                if (blockToCheck.typeId !== blockPermutation.type.id)
                    continue;
                const blockToCheckHalf = blockToCheck.permutation.getState('minecraft:vertical_half');
                if (blockToCheckHalf !== half)
                    continue;
                const blockToCheckDirection = blockToCheck.permutation.getState('minecraft:cardinal_direction');
                switch (direction) {
                    case Direction.East:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_left');
                            }
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'inner_right');
                            }
                        }
                        break;
                    case Direction.West:
                        {
                            if (blockToCheckDirection === 'south') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_left');
                            }
                            if (blockToCheckDirection === 'north') {
                                blockPermutation =
                                    blockPermutation.withState('pa:shape', 'outer_right');
                            }
                        }
                        break;
                    case Direction.North:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_right'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_right'));
                            }
                        }
                        break;
                    case Direction.South:
                        {
                            if (blockToCheckDirection === 'north') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'outer_left'));
                            }
                            if (blockToCheckDirection === 'south') {
                                blockToCheck.setPermutation(blockToCheck.permutation.withState('pa:shape', 'inner_left'));
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }
        break;
    default:
        break;
}
e.permutationToPlace = blockPermutation;
e.block.dimension.playSound("use.stone", e.block.location, { pitch: 0.8, volume: 1.0 });
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_proto_cana_dmacaco:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 3) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_cabomba:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 5) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_esporos_termitomyces:trigger', {
  onRandomTick: e => { const growthChance = 1 / 3;
if (Math.random() > growthChance) return;

const growth = e.block.permutation.getState("pa:growth");
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth + 1)
);
 },
onPlayerInteract: e => { if (!e.player) return;

const equippable = e.player.getComponent("minecraft:equippable");
if (!equippable) return;

const mainhand = equippable.getEquipmentSlot("Mainhand");
if (!mainhand.hasItem() || mainhand.typeId !== "minecraft:bone_meal")
    return;

let growth = e.block.permutation.getState("pa:growth");

if (growth >= 3) return;

growth += 1;
e.block.setPermutation(
    e.block.permutation.withState("pa:growth", growth)
);

if (mainhand.amount > 1) mainhand.amount--;
else mainhand.setItem(undefined);

const effectLocation = e.block.center();
e.dimension.playSound("item.bone_meal.use", effectLocation);
e.dimension.spawnParticle(
    "minecraft:crop_growth_emitter",
    effectLocation
);
 },
});

initEvent.blockComponentRegistry.registerCustomComponent('tmb_parede_arenito_areia_quartzo:trigger', {
  onPlayerDestroy: e => { for (const direction of DirectionType.HORIZONTAL) {
    const directionOpposite = getOppositeDirection(direction);
    const blockToCheck = e.block.offset(directionToVector3(directionOpposite));

    for (const directionChild of DirectionType.HORIZONTAL) {
        const directionOppositeChild = getOppositeDirection(directionChild);
        const blockToCheckChild = blockToCheck.offset(directionToVector3(directionOppositeChild));

        try {
            blockToCheck.setPermutation(blockToCheck.permutation.withState(`pa:${directionOppositeChild.toLowerCase()}`, !blockToCheckChild.typeId.includes("minecraft:air")));
        } catch (error) { }
    }
}
 },
beforeOnPlayerPlace: e => { e.permutationToPlace = e.permutationToPlace.withState("pa:in_world", true);

for (const direction of DirectionType.HORIZONTAL) {
    const directionOpposite = getOppositeDirection(direction);
    const blockToCheck = e.block.offset(directionToVector3(directionOpposite));

    if (blockToCheck.typeId.includes("minecraft:air")) continue;
    e.permutationToPlace = e.permutationToPlace.withState(`pa:${directionOpposite.toLowerCase()}`, !blockToCheck.typeId.includes("minecraft:air"));

    try {
        blockToCheck.setPermutation(blockToCheck.permutation.withState(`pa:${direction.toLowerCase()}`, true));
    } catch (error) { }
}
 },
});

});
